/// <reference types="node" />
import { S3 } from 'aws-sdk';
import { Readable, Writable } from "stream";
import { Bucket, BucketFile, BucketFileDeleted, BucketType } from "./bucket-base";
declare type AwsFile = S3.Object;
export interface AwsBucketCfg {
    bucketName: string;
    access_key_id: string;
    access_key_secret: string;
}
export declare function getAwsBucket(cfg: AwsBucketCfg): Promise<AwsBucket>;
declare class AwsBucket implements Bucket<AwsFile> {
    private s3;
    private baseParams;
    get type(): BucketType;
    get name(): string;
    constructor(s3: S3, bucketName: string);
    getPath(obj: AwsFile): string;
    exists(path: string): Promise<boolean>;
    getFile(path: string): Promise<BucketFile | null>;
    /**
     *
     * @param path prefix path or glob (the string before the first '*' will be used as prefix)
     */
    list(prefixOrGlob?: string): Promise<BucketFile[]>;
    copy(pathOrGlob: string, destDir: string | BucketFile): Promise<void>;
    download(pathOrGlob: string, localPath: string): Promise<BucketFile[]>;
    downloadAsText(path: string): Promise<string>;
    upload(localFileOrDirOrGlob: string, destPath: string): Promise<BucketFile[]>;
    uploadContent(path: string, content: string): Promise<void>;
    createReadStream(path: string): Promise<Readable>;
    createWriteStream(path: string): Promise<Writable>;
    delete(path: string): Promise<boolean>;
    deleteAll(files: BucketFile[]): Promise<BucketFileDeleted[]>;
    /**
     * List the googleFiles for this bucket;
     */
    listAwsFiles(prefixOrGlob?: string): Promise<AwsFile[]>;
    private toFile;
}
export {};
