/// <reference types="node" />
import { Bucket as GoogleBucket, File as GoogleFile } from '@google-cloud/storage';
import { Readable, Writable } from "stream";
import { Bucket, BucketFile, BucketFileDeleted, BucketType } from "./bucket-base";
export declare function getGcpBucket(cfg: GcpBucketCfg): Promise<GcpBucket>;
export interface GcpBucketCfg {
    bucketName: string;
    project_id: string;
    client_email: string;
    private_key: string;
}
declare class GcpBucket implements Bucket<GoogleFile> {
    readonly googleBucket: GoogleBucket;
    get type(): BucketType;
    get name(): string;
    constructor(googleBucket: GoogleBucket);
    getPath(obj: GoogleFile): string;
    exists(path: string): Promise<boolean>;
    getFile(path: string): Promise<BucketFile | null>;
    /**
     *
     * @param path prefix path or glob (the string before the first '*' will be used as prefix)
     */
    list(prefixOrGlob?: string): Promise<BucketFile[]>;
    copy(pathOrGlob: string, destDir: string | BucketFile): Promise<void>;
    download(pathOrGlob: string, localPath: string): Promise<BucketFile[]>;
    downloadAsText(path: string): Promise<string>;
    upload(localFileOrDirOrGlob: string, destPath: string): Promise<BucketFile[]>;
    uploadOld(localPath: string, destPath: string): Promise<BucketFile>;
    uploadContent(path: string, content: string): Promise<void>;
    createReadStream(path: string): Promise<Readable>;
    createWriteStream(path: string): Promise<Writable>;
    delete(path: string): Promise<boolean>;
    deleteAll(files: BucketFile[]): Promise<BucketFileDeleted[]>;
    toFile(this: GcpBucket, googleFile: GoogleFile): BucketFile;
    /**
     * List the googleFiles for this bucket;
     */
    listGoogleFiles(prefixOrGlob?: string): Promise<GoogleFile[]>;
}
export {};
